// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	ArrowButton.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_ArrowButton_h
#define _SCPP_ArrowButton_h

#include <scxx.h>
#include <GUITypes.h>
#include <GWidget.h>
#include <GWindow.h>
#include <EHArrowButton.h>

class PArrowButton;

/*
   ArrowButton is just like a PushButton, except that it only displays a directionnal arrow
   symbol. The arrow can point up, down, left, right.
   Visual effect is provided when it is pressed or released.
*/

active class ArrowButton : public GWidget,
                           public ArrowButtonEventHandler {
public:
			     
  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand
  //

  ArrowButton(GWindow &W, GUIDirection::Value direction,
	      int height=-1, int width=-1,
	      const char* objectName="ArrowButton", 
	      ArgList userOptions=0, Cardinal nUserOptions=0, 
	      Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Accepted only when the mouse is pressed and then released.
  void Pressed(Boolean sensitive=GUIBool::SENSITIVE, 
	       Boolean reset=GUIBool::NO_RESET);

  // The two following methods can be used for example to do something
  // from the time the button is pressed to the time the button is released.

  // Accepted only when the mouse is pressed, but not yet released.
  void MousePress(Boolean sensitive=GUIBool::SENSITIVE, 
		  Boolean reset=GUIBool::NO_RESET);

  // Accepted when the mouse has been released.
  void MouseRelease(Boolean sensitive=GUIBool::SENSITIVE, 
		    Boolean reset=GUIBool::NO_RESET);


  // Motif resources :
  void Resources(GUIDirection::Value direction=GUIDirection::DEFAULT,
		 GUIButtonMultiClick::Value multiClick= 
		 GUIButtonMultiClick::DEFAULT);

  PArrowButton *Passive();

  // private, callback entries
  void MousePressEvent();
  void PressedEvent();
  void MouseReleaseEvent();

private:
  @ArrowButton();

  PArrowButton *impl;
};

#endif /* _SCPP_ArrowButton_h */






