// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	Command.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_Command_h
#define _SCPP_Command_h

#include <scxx.h>
#include <GWidget.h>
#include <GWindow.h>
#include <EHCommand.h>
#include <ListTemplate.h>
#include <CharString.h>

class PCommand;

/*
   The Command object allows the user to enter commands and have them
   saved in a history list for later reference.
   It provides a text/command entry area and a command history area.
   The Command object also provides an event when a command is typed
   or double-clicked in the history list.
*/

active class Command : public GWidget,
                       public CommandEventHandler {

public:
  
  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  Command(GWindow &W, 
	  int historyMaxItems=100, int historyVisibleItemCount=-1,
	  const char* objectName="Command", 
	  ArgList userOptions=0, Cardinal nUserOptions=0, 
	  Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Accepted when a command is typed or double-clicked in the history list
  // Give back to the user the currently selected command in the command entry area
  // 'sensitive' parameter can be set in order to disable any further
  // reception of events on the Command
  // 'reset' parameter can be used to clear the event queue of the Command
  //
  void CommandEntered(CharString &command, 
		      Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET);

  // Motif resources :
  // historyItemCount resource is set to historyItems.Size().
  void Resources(const char *command=0,
		 /* ListTemplate<CharString> &historyItems=
		 ListTemplate<CharString>(), Compiler bug */
		 int historyMaxItems=-1,
		 int historyVisibleItemCount=-1,
		 const char *promptString=0);
  
  ~Command();

  void CommandEnteredEvent(); // private, callback entry

  PCommand *Passive();
  
private:
  
  @Command();
  int commandOn;
  PCommand *impl;
};

#endif /* _SCPP_Command_h */






