// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	DrawingArea.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_DRAWING_AREA_
#define _SCPP_DRAWING_AREA_

#include <scxx.h>
#include <GUI.h>
#include <GUITypes.h>
#include <GWindow.h>
#include <EHDrawingArea.h>
#include <GUIMirrorTypes.h>

class PDrawingArea;

/*
   DrawingArea is typically used for drawing or painting.
   The user can draw interactively geometric objects and paint arbitrary colors.
   DrawingArea is free-form object that can be used for application-specific purposes.
   DrawingArea informs user application when it is rezised or exposed,
   then application is responsible for providing all of the necessary redrawing.
   DrawingArea may also contain other objects as children, although there is no
   regimented layout policy.
*/

active class DrawingArea : public GWindow,
                           public DrawingAreaEventHandler {
public:

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  DrawingArea(GUI &gui, const char *windowTitle, 
	      int width=-1, int height=-1, int x=-1, int y=-1,
	      GUIResizePolicy::Value resizePolicy=GUIResizePolicy::ANY,
	      int marginWidthToChild=-1, int marginHeightToChild=-1,
	      const char *objectName="DrawingArea", 
	      ArgList userOptions=0, Cardinal nUserOptions=0, 
	      Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  DrawingArea(GWindow &W,
	      int width=-1, int height=-1, 
	      GUIResizePolicy::Value resizePolicy=GUIResizePolicy::ANY,
	      int marginWidth=-1, int marginHeight=-1,
	      const char *objectName="DrawingArea", 
	      ArgList userOptions=0, Cardinal nUserOptions=0,
	      Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  DrawingArea(DrawingArea &W,
	      int width=-1, int height=-1, 
	      GUIResizePolicy::Value resizePolicy=GUIResizePolicy::ANY,
	      int marginWidth=-1, int marginHeight=-1,
	      const char *objectName="DrawingArea", 
	      ArgList userOptions=0, Cardinal nUserOptions=0,
	      Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  virtual ~DrawingArea();

  // Clear the DrawingArea.
  virtual void Clear();

  // Get current dimension of the DrawingArea object
  int GetWidth() const;
  int GetHeight() const;
  void GetDimensions(int &width, int &height) const;
  
  // Accepted only when DrawingArea has been resized.
  void Resized();

  // Accepted only when a region of DrawingArea has been exposed.
  void Exposed(int &x, int &y, int &width, int &height);  
  void Exposed();

  // Motif Resources.
  void Resources(int marginHeight=-1,
		 int marginWidth=-1,
		 GUIResizePolicy::Value resizePolicy=GUIResizePolicy::DEFAULT);

  // private callback entries
  virtual void ResizedEvent();
  virtual void ExposedEvent();

  PDrawingArea *Passive();


  protected :

  // Methods used by derived (descendants) class.
  DrawingArea(Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Derivated class may call this method in top level container constructors.
  void InitImplementation(PDrawingArea *implm);


  private :

  PDrawingArea *impl;
  int           isMyImpl;

  @DrawingArea();
};


#endif //_SCPP_DRAWING_AREA_




