// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	FileSelection.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May 27 1997
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef __FileSelection__H__
#define __FileSelection__H__

#include <scxx.h>
#include <GUI.h>
#include <GWindow.h>

class PFileSelection;

/* This object allows the user to move through the file system and
   select a file or a directory. */


#include <scxx.h>
#include <GWidget.h>
#include <GWindow.h>
#include <EHFileSelection.h>
#include <CharString.h>

active class FileSelection : public GWidget,
                            public FileSelectionEventHandler {

public:
  
  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  FileSelection(GWindow &W, 
		const char *directory=0,
		const char *pattern=0,
		const char *directoryAndPattern=0, // XmNdirMask
		Boolean mustMatch=False,
		Boolean showOkButton=False,
		Boolean showCancelButton=False,
		Boolean showFilterButton=False,
		Boolean showHelpButton=False,
		Boolean showSeparator=False,
		const char *okButtonLabel=0,
		const char *cancelButtonLabel=0,
		const char *filterButtonLabel=0,
		const char *helpButtonLabel=0,
		const char *directoryListLabel=0,
		const char *fileListLabel=0,
		// fileTypeMask, // not implemented yet.
		const char *filterLabel=0,
		const char *selectionLabel=0,
		const char *noMatchString=0,
		const char* objectName="FileSelection", 
		ArgList userOptions=0, Cardinal nUserOptions=0, 
		Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Reinitialize the directory and file lists by applying the mask to
  // the file system.  It reads the directory filter and scans the
  // specified directory.

 void DoSearch(const CharString &mask);

 void GetSelection(CharString &selection);
 void GetValues(CharString &selection, CharString &directoryAndPattern);
 void GetValues(CharString &selection, CharString &directory, CharString &pattern);

  // accepted when a file is selected in the file list or when a file is
  // typed in the file text field (in this case there is not garantee
  // that the file exists).

 void SelectedFile(CharString &pathAndFile, 
		   Boolean sensitive=GUIBool::SENSITIVE, 
		   Boolean reset=GUIBool::NO_RESET);

 void NoMatch(CharString &text, 
	      Boolean sensitive=GUIBool::SENSITIVE, 
	      Boolean reset=GUIBool::NO_RESET);

 void Cancel(Boolean sensitive=GUIBool::SENSITIVE, 
	     Boolean reset=GUIBool::NO_RESET);

 void Help(Boolean sensitive=GUIBool::SENSITIVE, 
	   Boolean reset=GUIBool::NO_RESET);
  
  Boolean GetMustMatch() const;
  void    SetMustMatch(Boolean mustMatch);

#if 0
  // Motif resources :
  // historyItemCount resource is set to historyItems.Size().
  void Resources(const char *fileSelection=0,
		 ListTemplate<CharString> &historyItems=
		 ListTemplate<CharString>(),
		 int historyMaxItems=-1,
		 int historyVisibleItemCount=-1,
		 const char *promptString=0);
#endif
  
  ~FileSelection();

  void SelectedFileEvent(); // private, callback entry
  void NoMatchEvent(); // private, callback entry
  void CancelEvent(); // private, callback entry
  void HelpEvent(); // private, callback entry

  PFileSelection *Passive();
  
private:
  
  @FileSelection();
  PFileSelection *impl;
};

#endif
