// -*- Mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	GUIList.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_GUIList_h
#define _SCPP_GUIList_h

#include <scxx.h>
#include <GWidget.h>
#include <EHGUIList.h>
#include <GUITypes.h>
#include <CharString.h>
// #include <ListTemplate.h>

class PGUIList;

/*
 GUIList is a class base that implements the funcionalities communs to lists.
 Positions in GUIList start at 0, -1 is intended for "at end of GUIList".
*/

active class GUIList : public GWidget,
                    public ListEventHandler  {
public:

  GUIList(Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // 0 is intended by first position of items in the list.
  // -1 is intended by add at end of list.
  void Add(const CharString &newItem, int itemPosition=-1);
  // void Add(ListTemplate<CharString> &items, int startItemsPosition=-1);

  // Delete item(s). 
  void Delete(int itemPosition=-1); // delete specified item, defaut is last item
  void Delete(const CharString &item);
  // void Delete(ListTemplate<CharString> &items);
  // void Delete(ListTemplate<int> &itemPositions);

  // Delete all items in the list.
  void DeleteAll();

  // Delete all items in the list and add the items in newItems.
  // void ReplaceItems(ListTemplate<CharString> &newItems);

  // If item exist in the list, it is selected.
  // if notify is True, start un selection event.
  void TurnSelected(const CharString &item, Boolean notify=GUIBool::NO_NOTIFY);
  void TurnSelected(int positionToSelect, Boolean notify=GUIBool::NO_NOTIFY);

  // Deselected item, if it exist in the list.
  // if notify is True, start un selection event.
  void TurnDeselected(const CharString &item);
  void TurnDeselected(int positionToSelect);

  // Deselect all items.
  void DeselectAllItems();

  // Return True if item at position is selected.
  Boolean IsSelected(int itemPosition);

  // Set this element/position in the visible area of list.
  void SetVisible(int positionToVisible, GUISide::Value side=GUISide::TOP);
  void SetVisible(const CharString &item, GUISide::Value side=GUISide::TOP);

  // Get the item/position at top of visible area of list.
  // visibleSide may take GUISide::TOP or GUISide::BOTTOM values.
  int    GetVisible(GUISide::Value visibleSide=GUISide::TOP);

  // return the count of items.
  int NumberOfItems();

  // return items in list.
  // void GetItems(ListTemplate<CharString> &items) const;

  // return the count of visible items.
  int NumberOfVisibleItems();

  // Selected with a double click :

  // return selected item's position.
  int   DoubleClicked(Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET);

  // return selected item.
  void  DoubleClicked(CharString &item, 
		      Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET);

  // return selected item and selected item's position.
  void  DoubleClicked(CharString &item, int &position, 
		      Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET); 

  // Motif resources :
  // itemCount resource is set to items.Size();
  // selectedItemCount resource is set to selectedItems.Size();
  void Resource(Boolean automaticSelection=GUIBool::DEFAULT,
		int doubleClickInterval=-1,
		XmFontList fontList=XmFontList(-1),
		// ListTemplate<CharString> &items=ListTemplate<CharString>(),
		int listMarginHeight=-1,
		int listMarginWidth=-1,
		int listSpacing=-1,
		// ListTemplate<String> &selectedItems=ListTemplate<String>(),
		GUIListSelectionPolicy::Value selectionPolicy=
		GUIListSelectionPolicy::DEFAULT,
		GUIScrollBarDisplayPolicy::Value scrollBarDisplayPolicy=
		GUIScrollBarDisplayPolicy::DEFAULT,
		int topItemPosition=-1,
		int visibleItemCount=-1);

  Widget &WidgetToAttach();

  // private, callback entry.
  void DoubleClickedEvent();

  PGUIList *Passive();
  void InitImplementation(PGUIList *implm);

  private :
  @GUIList();

  PGUIList *impl;
};

#endif /* _SCPP_GUIList_h */
