#ifndef _SCPP_GUI_TYPES_H_
#define _SCPP_GUI_TYPES_H_

#include <GUIMirrorTypes.h>

/*
 general and global types used for instanciation of some of the GUI objects
*/

#ifndef True
#define True  1
#else
#if True != 1
#error "GUI expects a value of 1 for True."
#endif
#endif

#ifndef False
#define False  0
#else
#if False != 0
#error "GUI expects a value of 0 for False."
#endif
#endif

class GUIAlignment {
  public :
  enum Value { BEGIN, CENTER, END, DEFAULT=-1, UNDEFINED=-2};
};

class GUIAudibleWarning {
  public :
  enum Value {
    BELL,
    NONE,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIBool {
  public :

  const Boolean GUI_TRUE = True;
  const Boolean GUI_FALSE = !GUI_TRUE;  

  const Boolean DEFAULT = Boolean(-1);

  const Boolean ADJUST_LAST = GUI_TRUE;
  const Boolean NO_ADJUST_LAST = !ADJUST_LAST;

  const Boolean DISCARD = GUI_TRUE;
  const Boolean NO_DISCARD = !DISCARD;

  const Boolean EDITABLE = GUI_TRUE;
  const Boolean NO_EDITABLE = !EDITABLE;

  const Boolean NOTIFY = GUI_TRUE;
  const Boolean NO_NOTIFY = !NOTIFY;

  const Boolean ON= GUI_TRUE;
  const Boolean OFF= !ON;

  const Boolean RESET = GUI_TRUE;
  const Boolean NO_RESET = !RESET;

  const Boolean SENSITIVE = GUI_TRUE;
  const Boolean NO_SENSITIVE = !SENSITIVE;
  const Boolean INSENSITIVE = !SENSITIVE;

  const Boolean SEQUENTIAL = GUI_TRUE; 
  const Boolean NO_SEQUENTIAL = !SEQUENTIAL;

  const Boolean SHOW = GUI_TRUE;
  const Boolean NO_SHOW = !SHOW;

  const Boolean STATE_ON = GUI_TRUE;
  const Boolean NO_STATE_ON = !STATE_ON;
  const Boolean STATE_OFF = !STATE_ON;

  const Boolean TEAR_ON = GUI_TRUE;
  const Boolean TEAR_OFF = !TEAR_ON;
};

class GUIButtonMultiClick {
  public :
  enum Value {
    DISCARD, // ignore successive button clicks. Default in a menu system.
    KEEP,    // count successive button clicks. Default when not in a menu.
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUICommandLocation {
  public :
  enum Value {
    ABOVE_WORK_SPACE,
    BELOW_WORK_SPACE,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIDeleteResponse {
  public :
  enum Value {
    DESTROY,
    UNMAP,
    DO_NOTHING,
    DEFAULT = -1,
    UNDEFINED = -2 };
};


class GUIDialogStyle {
  public :
  enum Value {
    WORK_AREA,
    MODELESS,
    FULL_APPLICATION_MODAL,
    APPLICATION_MODAL,
    PRIMARY_APPLICATION_MODAL,
    SYSTEM_MODAL,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIDirection {
  public :
  enum Value {UP, DOWN, LEFT, RIGHT, DEFAULT=-1, UNDEFINED=-2};
};

class GUIKeyboardFocusPolicy {
  public :
  enum Value {
    EXPLICIT,
    POINTER,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIListSelectionPolicy {
  public :
  enum Value {
    SINGLE_SELECT,
    BROWSE_SELECT,
    MULTIPLE_SELECT,
    EXTENDED_SELECT,
    // with EXTENDED_SELECT, current selection is :
    // modified using SHIFT key in combination with a selection action.
    // added (augmented) using CTRL key in combination with a selection action.
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIListSizePolicy {
  public :
  enum Value {
    VARIABLE,
    CONSTANT,
    RESIZE_IF_POSSIBLE,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUINavigationType {
  public :
  enum Value {
    NONE,
    TAB_GROUP,
    STICKY_TAB_GROUP,
    EXCLUSIVE_TAB_GROUP,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIObjects {
  public :
  enum Values {
    ARROW_BUTTON,
    BASIC_PUSH_BUTTON,
    BULLETIN_BOARD,
    CHECK_BOX,
    COMMAND,
    DRAWING_AREA,
    FORM,
    GUI,
    GWIDGET,
    GWINDOW,
    LABEL,
    LABEL_PIXMAP,
    LIST,
    MAIN_WINDOW,
    MENU,
    MENU_BAR,
    MENU_BUTTON,
    MULTIPLE_SELECTION_LIST,
    OPTION_MENU,
    PANED_WINDOW,
    POP_UP_MENU,
    PULL_DOWN_MENU,
    PUSH_BUTTON,
    PUSH_BUTTON_PIXMAP,
    RADIO_BOX,
    ROW_COLUMN,
    SCALE,
    SCROLLED_WINDOW,
    SEPARATOR,
    SIMPLE_BUTTON_CONTAINER,
    SINGLE_SELECTION_LIST,
    TEXT,
    TEXT_FIELD,
    TOGGLE_BUTTON,
    XTERM
  };
};

class GUIOrientation {
  public :
  enum Value {VERTICAL, HORIZONTAL, DEFAULT=-1, UNDEFINED=-2};
};

class GUIPacking {
  public :
  enum Value {NONE, TIGHT, COLUMN, DEFAULT=-1, UNDEFINED=-2};
};

class GUIResizePolicy {
  public :
  enum Value {NONE, ANY, GROW, DEFAULT=-1, UNDEFINED=-2};
};

class GUIScrollBarDisplayPolicy {
  public :
  enum Value {
    STATIC,
    AS_NEEDED,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIScrollBarPlacement {
  public :
  enum Value {
    TOP_LEFT,
    BOTTOM_LEFT,
    TOP_RIGHT,
    BOTTOM_RIGHT,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUISeparatorType {
  public :
  enum Value { NO_LINE, 
	       SINGLE_LINE,        DOUBLE_LINE,
	       SINGLE_DASHED_LINE, DOUBLE_DASHED_LINE,
	       SHADOW_ETCHED_IN,   SHADOW_ETCHED_OUT, 
	       DEFAULT=-1,         UNDEFINED=-2 };
};

class GUIShadowType {
  public :
  enum Value {
    IN,
    OUT,
    ETCHED_IN,
    ETCHED_OUT,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUISide {
  public :
  enum Value {TOP, BOTTOM, LEFT, RIGHT, DEFAULT=-1, UNDEFINED=-2};
};

class GUIState {
  public :
  enum Value {ON, OFF, DEFAULT=-1, UNDEFINED=-2};
};

class GUIStringDirection {
  public :
  enum Value {LEFT_TO_RIGHT, RIGHT_TO_LEFT, DEFAULT=-1, UNDEFINED=-2};
};

class GUITextEditMode {
  public :
  enum Value { MULTI_LINE, SINGLE_LINE, DEFAULT=-1, UNDEFINED=-2};
};

class GUIUnitType {
  public :
  enum Value {
    PIXELS,
    _100TH_MILLIMETERS,
    _1000TH_INCHES,
    _100TH_POINTS,
    _100TH_FONT_UNITS,
    DEFAULT = -1,
    UNDEFINED = -2 };
};

class GUIVerticalAlignment {
  public :
  enum Value { BASE_LINE_BOTTOM,
	       BASE_LINE_TOP,
	       CONTENTS_BOTTOM,
	       CENTER, 
	       CONTENTS_TOP, 
	       DEFAULT=-1, UNDEFINED=-2};
};

#endif // _SCPP_GUI_TYPES_H_
