// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	GWidget.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Mon May  8 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_GWidget_h
#define _SCPP_GWidget_h

#include <scxx.h>
#include <GUIMirrorTypes.h>
#include <GUITypes.h>

class PGWidget;

/*
   Base class inherited by all GUI objects of the library.
*/

active class GWidget {
  
public:
  
  // sequential parameter: 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible 
  //      GUI events).
  //   By default reception in order of GUI events is not provided allowing 
  //      application to synchronize with GUI objects on demand.
  //
  GWidget(Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);
  
  // Turn sensitive/insensitive the objet.
  //
  void Sensitive(Boolean sensitive=GUIBool::SENSITIVE);

  // Set Foreground and Background colors.
  // colorName examples: 
  //      red,blue,grey25,grey50,grey75,brown,yellow,green,LightSteelBlue
  //
  void SetForegroundColor(const char *colorName);
  void SetBackgroundColor(const char *colorName);
  
  // Set Font
  // Used mainly with objects displaying text :
  //      Label, PushButton, ToggleButton, all Menus, Text, TextField and List.
  // Whitout effect when applied to PGWindow (ie Container) objects.
  // fontName example : "-Adobe-Times-Medium-I-Normal--10*"
  // xfonsel program shows others font names.
  //
  void SetFont(const char *fontName);

  // Set and Get Position coordenates :
  void SetXY(int x, int y);
  void GetXY(int &x, int &y) const ;

  // Attach methods are used to attach the object inside a Form container.
  // It can be attached to the border of the form, to itself or any other 
  // widgets contained in the same form container.
  // Attach methods may be used only with objects contained in Form.
  // For more details see Attachment examples and documentation.
  //
  virtual void NoneAttach(GUISide::Value side);
  virtual void FormAttach(GUISide::Value side,int offset=0);
  virtual void OppositeFormAttach(GUISide::Value side,int offset=0);
  virtual void WidgetAttach(GUISide::Value side,GWidget &object,int offset=0);
  virtual void OppositeWidgetAttach(GUISide::Value side,GWidget &object,
				    int offset=0);
  virtual void PositionAttach(GUISide::Value side,int position,
			      int fractionBase=-1, 
			      int offset=0);
  virtual void SelfAttach(GUISide::Value side,int offset=0);

  // These methods may only be used with objects contained in PanedWindow.
  //
  // Specify the maximum and minimum height possible values for the object
  // that can be used to resize when the PanedWindow container is resized.
  // Remark: if they have the same value, object cannot be resized and 
  //         PanedWindow don't draw a shash.
  //
  void SetPaneMaximum(int maximum);
  void SetPaneMinimum(int minimum);

  // Specify the object to be unresizable when PanedWindow container is resized
  //
  void LockPanedResize();

  // Display the object if the container is ready.
  // This method negociates the geometry with its container object
  //
  virtual void Manage();

  // Erase the object from its container
  //
  virtual void Unmanage();

  virtual ~GWidget();

  // Intended for Motif users.
  //
  /* Not implemented core resources :
     // Motif disaproves changes to predefined translations tables.
     XtAccelerators accelerators,

     // use Sensitive methode (difficult to define a default value).
     Boolean ancestorSensitive,

     // only can be set at GWindow creation.
     Colormap colormap,
     int depth,
     Boolean initialResourcesPersistent = GUIBool::DEFAULT,
     Screen *screen,

     // Motif disaproves changes to predefined translations tables.
     XtTranslations translations.

     AnyType(-1) is intended for Motif's default.
   */

  void CoreResources(Pixel backgroundColor = Pixel(-1),
		     Pixmap backgroundPixmap = Pixmap(-1),
		     Pixel borderColor = Pixel(-1),
		     Pixmap borderPixmap = Pixmap(-1),
		     int borderWidth = -1,
		     int height= -1,
		     Boolean mappedWhenManaged = GUIBool::DEFAULT,
		     Boolean sensitive = GUIBool::DEFAULT,
		     int width = -1,
		     int x = -1,
		     int y = -1);

  void PrimitiveResources(Pixel bottomShadowColor = Pixel(-1),
			  Pixmap bottomShadowPixmap = Pixmap(-1),
			  Pixel foreground = Pixel(-1),
			  Pixel highlight = Pixel(-1),
			  Boolean highlightOnEnter = GUIBool::DEFAULT,
			  Pixmap highlightPixmap = Pixmap(-1),
			  int highlightThickness = -1,
			  GUINavigationType::Value navigationType = 
			  GUINavigationType::DEFAULT,
			  int shadowThickness = -1,
			  Pixel shadowColor = Pixel(-1),
			  Pixmap shadowPixmap = Pixmap(-1),
			  Boolean traversalOn = GUIBool::DEFAULT,
			  GUIUnitType::Value unitType = 
			  GUIUnitType::DEFAULT);

  void RowColumResources(short indexPosition=-1);

  void FormResources(Boolean resizable=GUIBool::DEFAULT);

  void PanedWindowResources(Boolean allowResize=GUIBool::DEFAULT,
			    int paneMaximum=-1,
			    int paneMinimum=-1,
			    short positionIndex=short(-1),
			    Boolean skipAdjust=False);
			    
  void GetParentValues(ArgList, Cardinal nargs);
  void SetParentValues(ArgList, Cardinal nargs);
  void GetValues(ArgList, Cardinal nargs);
  void SetValues(ArgList, Cardinal nargs);
  // void SetFontList(const char *charsetName, const char *descriptionFont);
  Widget &GetWidget();

  PGWidget *Passive();

  // intended for X programmers.
  //
  Colormap GetColormap() const;
  Display *GetDisplay() const;
  Visual *GetVisual() const;
  Screen *GetScreen() const;
  Window GetWindow() const;
  
protected:
  
  // all events should be accepted by application 
  // (to guarantee sequence of events -between objects- and no loss of events).
  //
  Boolean sequentialBehavior;

  // Derivated class may call this method in constructor.
  void InitImplementation(PGWidget *implm);

  private :

  PGWidget *impl;
};

extern PGWidget & MyGPassive(GWidget &g);

#endif /* _SCPP_GWidget_h */
