// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: GWindow.h,v 1.1 1995/10/28 15:39:35 pineda Exp pineda $
// 
// Contens:	GWindow.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Mon May  8 1995
//
// $Author: pineda $
// $Date: 1995/10/28 15:39:35 $
// $Revision: 1.1 $
// $State: Exp $
// $Header: /users/pineda/scpp/src/GUI/RCS/GWindow.h,v 1.1 1995/10/28 15:39:35 pineda Exp pineda $
// $Locker: pineda $
// $Log: GWindow.h,v $
// Revision 1.1  1995/10/28 15:39:35  pineda
// Initial revision
//

#ifndef _SCPP_GWindow_h
#define _SCPP_GWindow_h

#include <scxx.h>
#include <GUIMirrorTypes.h>
#include <GUI.h>
#include <GWidget.h>

class PGWindow;

/*
   Base class inherited by all GUI container objects of the library.
   a container control size and localization of contained objects.
   ne pas specifier w,h car container s'adapte a taille de ses fils
*/

active class GWindow : public GWidget {

public:

  // Display the toplevel container and associated widget childs
  //
  void Realize();

  // Erase from display the toplevel container and associated widget childs
  // Destroy windows (release resources in the server).
  void Unrealize();


  // Display the object if the container is ready.
  // This method negociates the geometry with its container object
  //
  virtual void Manage();

  // Erase the object from its container
  // Do not destroy windows.
  virtual void Unmanage();

  // see (and use !!!) the ancestor's methods :
  // GWidget::Sensitive()

  virtual ~GWindow();

  // Motif resources :

  /* not implemented Manager Resources:
     // This resources only can be set at creation
     stringDirection,
   */
  // Others Manager's resources can be set by PGWidget::PrimitiveResources.
  void ManagerResources(Pixel highlightColor = Pixel(-1),
			Widget initialFocus = Widget(-1),
			Pixel topShadowColor = Pixel(-1),
			Pixmap topShadowPixmap = Pixmap(-1));
			
  void TopLevelShellResources(
       Boolean iconic = GUIBool::DEFAULT,
       const char *iconName = 0,
       Atom    iconNameEncoding = Atom(-1));

  /* Resources not implemented :
     
     // This resources only can be set at creation
     buttonFontList,
     labelFontList,
     textFontList,
    
   */

  void VendorShellResources(
       GUIAudibleWarning::Value audibleWarning=GUIAudibleWarning::DEFAULT,
       XmFontList defaultFontList=XmFontList(-1),
       GUIDeleteResponse::Value deleteResponse=GUIDeleteResponse::DEFAULT,
       const char *inputMethod=0,
       GUIKeyboardFocusPolicy::Value keyboardFocusPolicy=
       GUIKeyboardFocusPolicy::DEFAULT,
       int mwmDecorations=-1,
       int mwmFunctions=-1,
       int mwmInputMode=-1,
       const char *mwmMenu=0,
       const char *mwmPredictType=0,
       GUIUnitType::Value unitType=GUIUnitType::DEFAULT,
       Boolean useAsyncGeometry=GUIBool::DEFAULT);
       
       
  void WMShellResources(
       int baseHeight=-1,
       int baseWidth=-1,
       int heightInc=-1,
       Pixmap iconMask=Pixmap(-1),
       Pixmap iconPixmap=Pixmap(-1),
       Window iconWindow=Window(-1),
       int iconX=-1,
       int iconY=-1,
       int initialState=-1,
       Boolean input=GUIBool::DEFAULT,
       int maxAspectX=-1,
       int maxAspectY=-1,
       int maxHeight=-1,
       int maxWidth=-1,
       int minAspectX=-1,
       int minAspectY=-1,
       int minHeight=-1,
       int minWidth=-1,
       const char *title=0,
       Atom titleEncoding=Atom(-1),
       Boolean transient=GUIBool::DEFAULT,
       Boolean waitForWm=GUIBool::DEFAULT,
       int widthInc=-1,
       Window windowGroup=Window(-1),
       int winGravity=-1,
       int wmTimeout=-1);

  /* Not implemented Shell resources :
     // This resources only can be set at creation.
     Boolean allowShellResize=False,     
 
     // [avanced, dedicated, specialized] behavior.
     createPopUpChildrenProc,
   */
  void ShellResources(
       const char *geometry=0,
       Boolean overrideRedirect=GUIBool::DEFAULT,
       Boolean saveUnder=GUIBool::DEFAULT,
       Visual *visual=(Visual *)-1);

  // used in passive objects construction.
  //
  PGWindow *Passive();
  
protected:

  GWindow(GUI &gui, const char *appName, const char *appClass, 
	  int x, int y, ArgList userOptions, Cardinal nUserOptions=0, 
	  Boolean sequential=GUIBool::NO_SEQUENTIAL,
	  int debug = 0);
  GWindow(Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Derivated class may call this method in top level container constructors.
  void InitImplementation(PGWindow *implm);

  private :

  PGWindow *impl;
};

extern PGWindow & MyGPassive(GWindow &g);

#include <GUIRealizer.h>

#endif /* _SCPP_GWindow_h */



