// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	MainWindow.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_MainWindow_h
#define _SCPP_MainWindow_h

#include <scxx.h>
#include <GWindow.h>
#include <GUI.h>
#include <MenuBar.h>
#include <GWidget.h>

class PMainWindow;

/*
   MainWindow is the most used of all windows in an application.
   It is the focal point of the user's interactions with the program.
   MainWindow is designed to lay out a menuBar, a work area, horizontal and vertical
   scrollbars, a command area, and a message area.
   
   Once a menubar has been created by being child of the MainWindow, you simply tell
   the MainWindow to include it in the window layout by using SetMenuBar method.
   
   The command area is just a single-line text area for entering individually
   typed commands to application. For example a Command object can be used
   in the command area. However you do not necessarily have to use a Command object.
   A textfield object can be used instead to provide a simple command area.
   
   The message area is just an output-only area that is used for error and
   status messages as needed by an application
*/

active class MainWindow : public GWindow {
public:
  MainWindow(GUI &gui, const char* title, int x=-1, int y=-1, 
	     GUICommandLocation::Value commandLocation=
	     GUICommandLocation::DEFAULT,
	     int mainWindowMarginHeight=-1, int mainWindowMarginWidth=-1,
	     Boolean showSeparator=GUIBool::DEFAULT,
	     const char *objectName="MainWindow",
	     ArgList userOptions=0, Cardinal nUserOptions=0, 
	     Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // specify the object to be included in the menubar area
  void SetMenuBar(MenuBar &menuBar);
  
  // specify the object to be included in the command area
  void SetCommandArea(GWidget &commandArea);
  
  // specify the object to be included in the work area
  void SetWorkArea(GWidget &workArea);
  
  // specify the object to be included in the message area
  void SetMessageArea(GWidget &messageArea);

  // specify all objects to be included in the different areas
  void SetAreas(MenuBar &menuBar, GWidget &comandArea, 
		GWidget &workArea, GWidget &messageArea);

  // Motif Resources :
  void Resources(int mainWindowMarginHeight=-1, int mainWindowMarginWidth=-1,
		 Boolean showSeparator=GUIBool::DEFAULT);
  
  ~MainWindow();
  
  PMainWindow *Passive();
  
  private :
  PMainWindow *impl;
};

#endif /* _SCPP_MainWindow_h */






