// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	ManualScrolledWindow.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_ManualScrolled_WINDOW_H_
#define _SCPP_ManualScrolled_WINDOW_H_

#include <scxx.h>
#include <GUI.h>
#include <GWidget.h>
#include <GWindow.h>
#include <EHManualScrolledWindow.h>

class ManualScrolledWindowImpl;

/*
 The ManualScrolledWindow container object provides a viewing area into another,
 usually larger, visual object. The viewport may be adjusted by the user through
 the use of ScrollBars that are attached to the ManualScrolledWindow.

 Programmer gets information from users actions on ScrollBars and he
 is responsable to display contents according to these values.

 Programmer can configurate the ScrollBars to adecuate them to changes
 in content's size. 
*/

active class ManualScrolledWindow : public GWindow,
                                    public ManualScrolledWindowEventHandler {

public:

  // Scrollbars existance is defined by programmer.
  // ManualScrolledWindow may only be container of one object.
  // Example :
  //   ManualScrolledWindow SW(gui);   // ok.
  //   RowColumn       R(SW);    // ok, first object contained.
  //   OtherWindow     O(SW);    // error, only one object in ManualScrolledWindow.

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  // Mimics Motif notation (suposse the same integer logical units
  // between parameters) :
  //   contentsWidth        : Length of total contents.
  //   horizontalViewLength : Width of viewport
  //   horizontalPageLength : Length to move when a users moves the ScrollBar a page 
  //                          (clicks in a region out of ScrollBar)
  //   horizontalIncrement  : Length to move when user clicks in a incremental arrow.
  //   Value                : Position of ScrollBar.

  ManualScrolledWindow(GUI &gui, const char *windowTitle, int x=-1, int y=-1,
		       Boolean horizontalScrollBar = GUIBool::SHOW,
		       Boolean verticalScrollBar = GUIBool::SHOW,
		       int horizontalMinimum=0, int horizontalMaximum=1,
		       int verticalMinimum=0, int verticalMaximum=1,
		       int horizontalViewLength=1, int verticalViewLength=1,
		       int horizontalPageLength=1, int verticalPageLength=1,
		       int horizontalIncrement=1, int verticalIncrement=1,
		       int horizontalValue=0, int verticalValue=0,
		       const char *objectName="ManualScrolledWindow",
		       ArgList userOptions=0, Cardinal nUserOptions=0, 
		       Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  ManualScrolledWindow(GWindow &parent,
		       Boolean horizontalScrollBar = GUIBool::SHOW,
		       Boolean verticalScrollBar = GUIBool::SHOW,
		       int horizontalMinimum=0, int horizontalMaximum=1,
		       int verticalMinimum=0, int verticalMaximum=1,
		       int horizontalViewLength=1, int verticalViewLength=1,
		       int horizontalPageLength=1, int verticalPageLength=1,
		       int horizontalIncrement=1, int verticalIncrement=1,
		       int horizontalValue=0, int verticalValue=0,
		       const char *objectName="ManualScrolledWindow",
		       ArgList userOptions=0, Cardinal nUserOptions=0, 
		       Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  ManualScrolledWindow(ManualScrolledWindow &parent,
		       Boolean horizontalScrollBar = GUIBool::SHOW,
		       Boolean verticalScrollBar = GUIBool::SHOW,
		       int horizontalMinimum=0, int horizontalMaximum=1,
		       int verticalMinimum=0, int verticalMaximum=1,
		       int horizontalViewLength=1, int verticalViewLength=1,
		       int horizontalPageLength=1, int verticalPageLength=1,
		       int horizontalIncrement=1, int verticalIncrement=1,
		       int horizontalValue=0, int verticalValue=0,
		       const char *name="ManualScrolledWindow", 
		       ArgList userOptions=0, Cardinal nUserOptions=0, 
		       Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);


  // Methods indicating user actions.
  // return a positive value indicating the new position of the
  // scrollbars (top value for horizontal scrollbar and left value for
  // vertical scrollbar.

  int HorizontalValueChanged() const;

  int VerticalValueChanged() const;


  // Methods to get and set (change, configurate) the scrollbars.

  void GetHorizontalValues(int &value, int &minimun, int &maximun,
			   int &viewWidth, int &pageWidth,
			   int &increment) const;

  void GetVerticalValues(int &value, int &minimun, int &maximun,
			 int &viewHeight, int &pageHeight,
			 int &increment) const;

  void SetHorizontalValues(int value, int minimun, int maximun,
			   int viewWidth, int pageWidth, int increment);

  void SetVerticalValues(int value, int minimun, int maximun,
			 int viewHeight, int pageHeight, int increment);


  // Motif resources :
  void Resources(GUIScrollBarPlacement::Value scrollBarPlacement=
		 GUIScrollBarPlacement::DEFAULT,
		 int scrolledWindowMarginHeight=-1,
		 int scrolledWindowMarginWidth=-1,
		 int spacing=-1);
  
  ~ManualScrolledWindow();

  ManualScrolledWindowImpl *Passive();

  // private Callback entries.

  void HorizontalValueChangedEvent();

  void VerticalValueChangedEvent();


  private :

  @ManualScrolledWindow();

  ManualScrolledWindowImpl *impl;
};

#endif // _ManualScrolled_WINDOW_H_
