// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	PullDownMenu.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_PullDownMenu_h
#define _SCPP_PullDownMenu_h


#include <scxx.h>
#include <Menu.h>
#include <MenuBar.h>

class PPullDownMenu;

/*
 PullDownMenu that are posted from the MenuBar are the most common menus
 in an application. PullDownMenu pops up when the user presses the first mouse button
 in a PullDownMenu (parameter name) that appears in a MenuBar or another PullDownMenu.
 A PullDownMenu can contain MenuButtons, ToggleButtons or other PullDownMenus.
*/

active class PullDownMenu : public Menu {

public:

  // tearOffOn :
  //   this parameter allows menus to be torn off and placed in separate windows.
  //   From the user's perspective, tear-off menus make it easy to make repetead menu
  //   selections. Normally, when the user posts a menu, it is only displayed until
  //   she makes a selection, and then it is removed. If the menu has been torn off,
  //   however, it is displayed in a separate window, and the user can make
  //   as many selections as he wants without having to repost it each time.
  //   The mremians torn off until the user cancels the menu pressing the 
  //   ESCAPE key within the window.
  // helpMenu :
  //   specifies that the PullDownMenu corresponds to a help menu and
  //   is displayed at the right end menubar
  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  PullDownMenu(MenuBar &M, const char* str, Boolean tearOffOn=True, 
	       char mnemonic='\0', Boolean helpMenu=GUIBool::GUI_FALSE, 
	       const char* objectName=0, 
	       ArgList userOptions=0, Cardinal nUserOptions=0, 
	       Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  PullDownMenu(PullDownMenu &M, const char* str, Boolean tearOffOn=False, 
	       char mnemonic='\0', const char* objectName=0,  
	       ArgList userOptions=0, Cardinal nUserOptions=0, 
	       Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Motif Resources :
  void Resources(Pixmap cascadePixmap=Pixmap(-1),
		 int mappingDelay=-1,
		 Boolean tearOffModel=GUIBool::DEFAULT,
		 const char *labelString=0);

  PPullDownMenu *Passive();

  ~PullDownMenu();

  private :

  PPullDownMenu *impl;
};

extern PPullDownMenu &MyGPassive(PullDownMenu &g);

#endif /* _SCPP_PullDownMenu_h */
