#ifndef _SCPP_PushButton_h
#define _SCPP_PushButton_h

#include <scxx.h>
#include <GUIMirrorTypes.h>
#include <BasicPushButton.h>
#include <GWindow.h>

class PPushButton;

/*
 PushButton supports the same visual display capabilities as a Label,
 In addition, the PushButton provides a method for the programmer to
 wait for the event activated when the user clicks on the button.
 Visual effects are automatically provided when the button is pressed and released,
 and when the pointer moves into the button.
*/

active class PushButton : public BasicPushButton {
public:

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand
  // bdefault: if True and this button is a child of a BulletinBoard,
  //           when the <return> key is pressed it specifies that
  //           this button is the default button to be activated on this event.

  PushButton(GWindow &W, const char* str, const char* objectName=0,
	     ArgList userOptions=0, Cardinal nUserOptions=0,
	     Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  // Motif Resources :
  void Resources(Pixel armColor=Pixel(-1),
		 int defaultButtonShadowThickness=-1,
		 Boolean fillOnArm=GUIBool::DEFAULT,
		 GUIButtonMultiClick::Value multiClick=
		 GUIButtonMultiClick::DEFAULT,
		 int showAsDefault=-1,
		 GUIAlignment::Value alignment=GUIAlignment::DEFAULT,
		 XmFontList fontList=XmFontList(-1),
		 const char *labelString=0,
		 int marginBottom=-1,
		 int marginHeight=-1,
		 int marginLeft=-1,
		 int marginRight=-1,
		 int marginTop=-1,
		 int marginWidth=-1,
		 Boolean recomputeSize=GUIBool::DEFAULT);     
		 
  PPushButton *Passive();
		 
  ~PushButton();

  private :
  
  PPushButton *impl;
};

#endif /* _SCPP_PushButton_h */






