// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	RadioBox.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_RadioBox_h
#define _SCPP_RadioBox_h

#include <scxx.h>
#include <GWindow.h>
#include <SimpleButtonContainer.h>

class PRadioBox;

/*
 When a set of ToggleButtons are used as part of an interface, it is in the form
 of a RadioBox or a CheckBox. The primary difference between the two is the selection
 of the ToggleButtons within. In a RadioBox, only one item may be selected at a time
 (analogous to old-style AM car radios). You can push one button and the previously
 set button pops up.
 A RadioBox is only composed of ToggleButtons.
*/

active class RadioBox : public SimpleButtonContainer {

 public:

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  // tight packing (see RoowColum).
  RadioBox(GWindow &W, 
	   GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	   const char *name="RadioBox",
	   ArgList wargs=0, Cardinal nUserOptions=0, 
	   Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // column packing (see RoowColum).
  RadioBox(GWindow &W, int numRowColumn, 
	   GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	   const char *name="RadioBox",
	   ArgList wargs=0, Cardinal nUserOptions=0, 
	   Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Motif Resources (from RowColumn) :
  void Resources(Boolean adjustLast=GUIBool::DEFAULT,
		 Boolean adjustMargin=GUIBool::DEFAULT,
		 GUIAlignment::Value entryAlignment=GUIAlignment::DEFAULT,
		 int entryBorder=-1,
		 GUIVerticalAlignment::Value entryVerticalAlignment=
		 GUIVerticalAlignment::DEFAULT,
		 Boolean isAligned=GUIBool::DEFAULT,
		 int marginHeight=-1,
		 int marginWidth=-1,
		 short numColumns=-1,
		 GUIOrientation::Value orientation=GUIOrientation::DEFAULT,
		 GUIPacking::Value packing=GUIPacking::DEFAULT,
		 Boolean resizeHeight=GUIBool::DEFAULT,
		 Boolean resizeWidth=GUIBool::DEFAULT,
		 int spacing=-1);

  PRadioBox *Passive();

  ~RadioBox();

  private :

  PRadioBox *impl;
};

extern PRadioBox &MyGPassive(RadioBox &g);

#endif /* _SCPP_RadioBox_h */
