// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	RowColumn.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Mon May  8 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_RowColumn_h
#define _SCPP_RowColumn_h


#include <scxx.h>
#include <GUITypes.h>
#include <GUI.h>
#include <GWindow.h>

class PRowColumn;

/*
   Container object which functionality is to layout contained objects in rows and columns.
   Constructors implement 'tight' or 'column' packing.
   Number of columns or rows can be specified only in 'column' packing mode.
*/

active class RowColumn : public GWindow {

public:

  // tight packing : 
  // Contained objects are layed one after other (if possible)
  // vertically or horizontally. 
  // Generally only one column (row) is obtained for vertical (horizontal)
  // orientation.
  // height (width) is particular to each object for vertical (horizontal)
  // orientation.
  // width (height) is the same for all objects and it is 
  // calculated from widest (heightest) object.
  // 
  // Parameters :
  //
  // adjustLast  : if True and vertical (horizontal) orientation, 
  //               objects in rightest column (bottom row) are resized when 
  //               RowColumn is resized.
  //
  RowColumn(GUI &gui, const char* windowTitle,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	    int x=-1, int y=-1, Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char *objectName="RowColumn",
	    ArgList userOptions=0, Cardinal nUserOptions=0,
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  RowColumn(GWindow &W,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	    Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char* objectName="RowColumn", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  RowColumn(RowColumn &W,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	    Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char* objectName="RowColumn", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);
  

  // column packing.
  //
  // Objects are layed in rows and columns.
  // All objects will have the same width and height.
  // width (height) is obtained from widest (heigest) object.
  // Generally used if all contained objects have same type.
  //
  // Parameters :
  //
  // nbRowColumn : number of columns  (rows) for vertical (horizontal)
  //               orientation (see example).
  // adjustLast  : if True and vertical (horizontal) orientation, 
  //               objects in rightest column (last row) are resized when 
  //               RowColumn is resized.
  // orientation : when orientation is VERTICAL (HORIZONTAL), children
  //               are added vertically (horizontally) so that each column
  //               is filled up before the next one is started.
  //
  // examples of layouts for 7 objects contained in a RowColum, 
  // numbers represent inclusion order :
  // 
  // ......
  //
  // RowColumn Main(gui, nbRowColumn, "Layout_example", GUIOrientation::..., );
  // Object    o1(Main, ....);
  // Object    o2(Main, ....);
  // Object    o3(Main, ....);
  //
  // ....
  //
  //
  // column packing and vertical orientation :
  //
  // number of columns       2             3                4
  //
  // layout               o1  o5      o1  o4  o7      o1  o3  o5  o7
  //                      o2  o6      o2  o5          o2  o4  o6
  //                      o3  o7      o3  o6
  //                      o4
  //
  // column packing and horizontal orientation:
  //
  // number of rows :        2             3                4
  //
  // layout             o1 o2 o3 o4     o1 o2 o3          o1 o2
  //                    o5 o6 o7        o4 o5 o6          o3 o4
  //                                    o7                o5 o6
  //                                                      o7
  //
  RowColumn(GUI &gui, int nbRowColumn, const char* windowTitle, 
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL, 
	    int x=-1,int y=-1, Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char *objectName="RowColumn",
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  RowColumn(GWindow &W, int nbRowColumn,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL, 
	    Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char* objectName="RowColumn", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  RowColumn(RowColumn &W, int nbRowColumn,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL, 
	    Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char* objectName="RowColumn", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);


  // user specified packing.
  RowColumn(GUI &gui, int nbRowColumn, GUIPacking::Value packing,
	    const char* windowTitle,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	    int x=-1,int y=-1, Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char *objectName="RowColumn",
	    ArgList userOptions=0, Cardinal nUserOptions=0,
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  RowColumn(GWindow &W, int nbRowColumn, GUIPacking::Value packing,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	    Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char* objectName="RowColumn", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  RowColumn(RowColumn &W, int nbRowColumn, GUIPacking::Value packing,
	    GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	    Boolean adjustLast=GUIBool::ADJUST_LAST, 
	    const char* objectName="RowColumn", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug = 0);

  // Motif resources :
  
  /* Not implemented RowColumn resources :
     WidgetClass entryClass, // Valid only for Box and MenusBar.
     Boolean isHomogeneus=False, // valid for CheckBox and MenuBar. 
     
   */
  void Resources(Boolean adjustLast=GUIBool::DEFAULT,
		 Boolean adjustMargin=GUIBool::DEFAULT,
		 GUIAlignment::Value entryAlignment=GUIAlignment::DEFAULT,
		 int entryBorder=-1,
		 GUIVerticalAlignment::Value entryVerticalAlignment=
		 GUIVerticalAlignment::DEFAULT,
		 Boolean isAligned=GUIBool::DEFAULT,
		 int marginHeight=-1,
		 int marginWidth=-1,
		 short numColumns=-1,
		 GUIOrientation::Value orientation=GUIOrientation::DEFAULT,
		 GUIPacking::Value packing=GUIPacking::DEFAULT,
		 Boolean resizeHeight=GUIBool::DEFAULT,
		 Boolean resizeWidth=GUIBool::DEFAULT,
		 int spacing=-1);
       

  PRowColumn *Passive();

  private :

  PRowColumn *impl;
};

#endif /* _SCPP_RowColumn_h */






