// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: Scale.h,v 1.1 1995/10/28 13:45:49 pineda Exp pineda $
// 
// Contens:	Scale.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: pineda $
// $Date: 1995/10/28 13:45:49 $
// $Revision: 1.1 $
// $State: Exp $
// $Header: /users/pineda/scpp/src/GUI/RCS/Scale.h,v 1.1 1995/10/28 13:45:49 pineda Exp pineda $
// $Locker: pineda $
// $Log: Scale.h,v $
// Revision 1.1  1995/10/28 13:45:49  pineda
// Initial revision
//

#ifndef _SCPP_Scale_h
#define _SCPP_Scale_h

#include <scxx.h>
#include <GUITypes.h>
#include <GWidget.h>
#include <GWindow.h>
#include <EHScale.h>

class PScale;

/*
 Scale displays a numeric value that falls whitin upper and lower bounds.
 The object allows the user to change that value interactively using
 a slider mechanism similar to that of a ScrollBar.
 The program can also change the current value of the Scale dynamically
 for example to use it as a gauge.
 A Scale can be oriented vertically or horizontally.
*/

active class Scale : public GWidget,
                     public ScaleEventHandler {
public:

// The value of a Scale can only be stored as an integer.
// If you need to represent fractional values, you must use the decimalPoint
// parameter.
// There is no limit to the values that can be specified for min, max parameters
// provided they can be represented by the int type, which include negative numbers.

// Parameters can be
// showValue: if True will display the upper and lower bounds.
// decimalPoint: this resource specifies the number of places to move the decimal point
//               to the left in the displayed value, which gives the user the impression
//               that the value displayed is fractional.
//               For example a Scale used to display the value of a barometer might range from 29
//               to 31, with a granularity of 1-100th. The necessary object coule be created as shown
//               in the following code fragment:
//     Scale(myParent,2900,3100,True,2,...);
//     The value decimalPoints is 2, so that the value displayed is 30.00 rather than 3000
// nameIsLabel: if True, the "name" parameter will appear as a label positionned next to Scale.
// sequential :
//   If set to True it enforces sequential behavior of events :
//      Application must always accept related events to this object in order
//      to receive the next GUI event (avoid deadlocks with other possible GUI events)
//   By default reception in order of GUI events is not provided allowing application
//      to synchronize with GUI objects on demand

  Scale(GWindow &W, int min=0, int max=100, Boolean showValue=GUIBool::NO_SHOW,
	int decimalPoints=0,
	GUIOrientation::Value orientation=GUIOrientation::VERTICAL,
	GUISide::Value maxPosition=GUISide::DEFAULT,
	int height=-1,int width=-1,
	const char* titleString=0, const char* name="Scale",
	ArgList userOptions=0, Cardinal nUserOptions=0,
	Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // 'sensitive' parameter can be set in order to disable any further
  // reception of events on the Scale
  // 'reset' parameter can be used to clear the event queue of the Scale

  // Accepted when when slider is released .
  // Return the current value of slider.
  int ReleaseValue(Boolean sensitive=GUIBool::SENSITIVE, 
		   Boolean reset=GUIBool::NO_RESET);

  // Accepted when slider has been dragged.
  // Return the current value of slider.
  int DragValue(Boolean sensitive=GUIBool::SENSITIVE, 
		Boolean reset=GUIBool::NO_RESET);

  // not blocking get value methode.
  int GetValue(); 
  void SetValue (int value);

  void SetParameters(int maximun, int minimun, int decimalPoints, int value);
  void GetParameters(int &maximun, int &minimun, 
		     int &decimalPoints, int &value) const;

  // Motif resources :
  void Resources(int decimalPoints=-1,
		 XmFontList fontList=XmFontList(-1),
		 Boolean highlightOnEnter=GUIBool::DEFAULT,
		 int highlightThickness=-1,
		 int maximum=-1,
		 int minimum=-1,
		 GUIOrientation::Value orientation=GUIOrientation::DEFAULT,
		 GUISide::Value maxPosition=GUISide::DEFAULT,
		 int scaleHeight=-1,
		 int scaleMultiple=-1,
		 int scaleWidth=-1,
		 Boolean showValue=GUIBool::DEFAULT,
		 const char *titleString=0,
		 int value=-1);

  void ReleaseEvent();  // private, callback entry
  void DragEvent();  // private, callback entry

  ~Scale();

  PScale *Passive();

  private :

  PScale *impl;

  @Scale();
};

#endif /* _SCPP_Scale_h */






