// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	ScrolledWindow.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_SCROLLED_WINDOW_H_
#define _SCPP_SCROLLED_WINDOW_H_

#include <scxx.h>
#include <GUI.h>
#include <GWidget.h>
#include <GWindow.h>

class PScrolledWindow;

/*
 The ScrolledWindow container object provides a viewing area into another,
 usually larger, visual object. The viewport may be adjusted by the user through
 the use of ScrollBars that are attached to the ScrolledWindow
*/

active class ScrolledWindow : public GWindow {

public:
  // Scrollbars are automatic (they appear if needed).
  // ScrolledWindow may only be container of one object.
  // Example :
  //   ScrolledWindow SW(gui);   // ok.
  //   RowColumn       R(SW);    // ok, first object contained.
  //   OtherWindow     O(SW);    // error, only one object in ScrolledWindow.

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  ScrolledWindow(GUI &gui, const char *windowTitle, int x=-1, int y=-1,
		 const char *objectName="ScrolledWindow", 
		 ArgList userOptions=0, Cardinal nUserOptions=0, 
		 Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  ScrolledWindow(GWindow &parent,
		 const char *name="ScrolledWindow", 
		 ArgList userOptions=0, Cardinal nUserOptions=0, 
		 Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  ScrolledWindow(ScrolledWindow &parent,
		 const char *name="ScrolledWindow", 
		 ArgList userOptions=0, Cardinal nUserOptions=0, 
		 Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Motif resources :
  void Resources(GUIScrollBarDisplayPolicy::Value scrollBarDisplayPolicy=
		 GUIScrollBarDisplayPolicy::DEFAULT,
		 GUIScrollBarPlacement::Value scrollBarPlacement=
		 GUIScrollBarPlacement::DEFAULT,
		 int scrolledWindowMarginHeight=-1,
		 int scrolledWindowMarginWidth=-1,
		 int spacing=-1);
  
  ~ScrolledWindow();

  PScrolledWindow *Passive();

  private :

  PScrolledWindow *impl;
};

#endif // _SCROLLED_WINDOW_H_
