// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	SingleSelectionList.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_SingleSelectionList_h
#define _SCPP_SingleSelectionList_h

#include <scxx.h>
#include <GWindow.h>
#include <GUIList.h>
#include <EHSingleSelectionList.h>
// #include <ListTemplate.h>
#include <CharString.h>
#include <GUIMirrorTypes.h>

class PSingleSelectionList;

/*
   A list object displays a single column of text choices that can be
   selected using either the mouse or the keyboard.
   Each choice is represented by a single-line text element specified
   as a CharString object.
   User can select only one item from SingleSelectionList.
   Selecting a new item deselects any other selected item, but there can never be a state
   where no items are selected: There is an initial selected item.
   SingleSelectionList should be used when only one of many choices may be selected at a time.
   Some possible uses for a single selection list include choosing a font family or
   style for text inpout and choosing a color for a bitmap editor.
*/
active class SingleSelectionList : public SingleSelectionListEventHandler, 
                                   public GUIList {
 public:

  // height of object is determinated by (priority order) :
  //   container's settings.
  //   itemsCount (-1 is intended for Motif's default).
  //   height     (-1 is intended for Motif's default).
  //   vertical scrollbar is set if needed.
  
  // width of object is determinated by (priority order) :
  //   container's settings.
  //   width      (-1 is intended for Motif's default).
  //   horizontal scrollbar is set if needed.

  // item counters are starting from 0

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  SingleSelectionList(GWindow &W, 
		      short visibleItemsCount=-1,
		      int numCharWidth=-1,
		      /* ListTemplate<CharString> &items=
		      ListTemplate<CharString>(), */
		      GUIListSizePolicy::Value listSizePolicy=
		      GUIListSizePolicy::DEFAULT,
		      const char *name="SingleSelectionList", 
		      ArgList wargs=0, Cardinal nUserOptions=0,
		      Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

  // Return selected item and/or position.
  // Items position starts in 0.
  // 'sensitive' parameter can be set in order to disable any further
  // reception of events on the SingleSelectionList
  // 'reset' parameter can be used to clear the event queue of the SingleSelectionList

  // return selected item's position.
  int   SingleClicked(Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET);

  // return selected item.
  void  SingleClicked(CharString &item, 
		      Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET);

  // return selected item and selected item's position.
  void  SingleClicked(CharString &item, int &position, 
		      Boolean sensitive=GUIBool::SENSITIVE, 
		      Boolean reset=GUIBool::NO_RESET); 

  // Return currently selected item and/or position.
  // These functions are always accepted.
  // positions start in 0. If there isn't a selection, position will be XXXX
  int   GetCurrentSelection();                   // selected item's position.
  void  GetCurrentSelection(CharString &item);   // selected item.
  void  GetCurrentSelection(CharString &item, int &position);

  ~SingleSelectionList();
  
  // private, callback entry.
  void SingleClickedEvent();

  PSingleSelectionList *Passive();

  private :

  @SingleSelectionList();
  
  PSingleSelectionList *impl;
};

#endif /* _SCPP_SingleSelectionList_h */
