#ifndef _SCPP_Text_h
#define _SCPP_Text_h

#include <scxx.h>
#include <TextField.h>
#include <EHTextField.h>
#include <CharString.h>
#include <GUIMirrorTypes.h>

class PText;

/*
   Text object provides full-featured text editing capabilities.
   The Text object can be used anywhere the user might be expected to type free-form
   text, such as in a compose window in a mail application.
   It supports the point-and-click model that people expect from GUI-based applications.
   Text object can be used in a output-only mode to display textual information
   then in practical with a label or a button.
*/

active class Text : public TextField {

public:

  // sequential : 
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  Text(GWindow &W, 
       int nRows=-1, int nColumns=-1, 
       Boolean horizontalScrollbar=GUIBool::SHOW,
       Boolean verticalScrollbar=GUIBool::SHOW,
       Boolean editable=GUIBool::EDITABLE, 
       const char *name="Text", ArgList wargs=0, Cardinal nUserOptions=0, 
       Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);
  
  // Insert text newText at "motif insert cursor" position.
  void InsertText(const CharString &newText);
  void InsertText(const char *newText);
  
  // Append text given in parameter at end of the text inside
  // Text object.
  void AppendText(const CharString &text, Boolean showNewText=True,
		  Boolean flush=True);
  void AppendText(const char *text, Boolean showNewText=True,
		  Boolean flush=True);
  
  // Motif resources :
  void Resources(Boolean autoShowCursorPosition=GUIBool::DEFAULT,
		 // Determinates key bindings.
		 GUITextEditMode::Value editMode=GUITextEditMode::DEFAULT,
		 XmTextSource source=XmTextSource(-1),
		 int topCharacter=-1,
		 Boolean resizeHeight=GUIBool::DEFAULT,
		 short rows=-1,
		 Boolean wordWrap=GUIBool::DEFAULT,
		 Boolean scrollHorizontal=GUIBool::DEFAULT,
		 Boolean scrollVertical=GUIBool::DEFAULT,
		 Boolean scrollLeftSide=GUIBool::DEFAULT,
		 Boolean scrollTopSide=GUIBool::DEFAULT);
  
  ~Text();

  PText *Passive();

  Widget &WidgetToAttach();

  private :

  PText *impl;
};

#endif /* _SCPP_Text_h */
