// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	TextField.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_TextField_h
#define _SCPP_TextField_h

#include <scxx.h>
#include <GWidget.h>
#include <GWindow.h>
#include <EHTextField.h>
#include <CharString.h>

class PTextField;

/*
   TextField provides a single-line data entry field.
   It provides full-featured text editting capabilities.
*/

active class TextField : public GWidget,
                         public TextFieldEventHandler {

public:

  // sequential :
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  TextField(GWindow &W, int nColumns=-1,
	    Boolean editable=GUIBool::EDITABLE,
	    const char *objectName= "TextField", 
	    ArgList userOptions=0, Cardinal nUserOptions=0, 
	    Boolean sequential=GUIBool::NO_SEQUENTIAL, int debug=0);
			       
  // Return the text content currently in TextField object.
  // The text storage is dynamically allocated by CharString class.
  //
  void GetText(CharString &text);

  // Clear TextField object, then
  // write text in TextField object (replace the old content).
  //
  void ReplaceText(const CharString &text);

  // Erase text content from TextField display, the content is lost.
  //
  void Clear();

  // Enable or disable edition.
  void SetEditable(Boolean editable=GUIBool::EDITABLE);

  // The user typed enter (full-filled text information has been entered).
  // Accepted when <return> key is pressed.
  //
  void ReadText(CharString &text, Boolean sensitive=True, Boolean reset=False);

  // Motif Resources.
  void Resources(int blinkRate=-1,
		 short columns=-1,
		 int cursorPosition=-1,
		 Boolean cursorPositionVisible=GUIBool::DEFAULT,
		 Boolean editable=GUIBool::DEFAULT,
		 XmFontList fontList=XmFontList(-1),
		 int marginHeight=-1,
		 int marginWidth=-1,
		 int maxLength=-1,
		 Boolean pendingDelete=GUIBool::DEFAULT,
		 Boolean resizeWidth=GUIBool::DEFAULT,
		 int selectThreshold=-1,
		 char *value=0,
		 Boolean verifyBell=GUIBool::DEFAULT);

  ~TextField();

  // Don't use. Intended to bypass a gnu's compiler bug.
  TextField(TextField &dummy);

  PTextField *Passive();

  void InitImplementation(PTextField *implm);

  // Comunicate the "active" motif's event.
  void ReadTextEvent(); // private, callback entry.

protected:

  // Constructor by derived classes.
  TextField(Boolean Sequential=GUIBool::NO_SEQUENTIAL, int debug=0);

private:

  PTextField *impl;

  // indicates if I must delete impl.
  int  myImpl;
  
  @TextField();
};

#endif /* _SCPP_TextField_h */
