// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	ToggleButton.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_ToggleButton_h
#define _SCPP_ToggleButton_h

#include <scxx.h>
#include <CheckBox.h>
#include <RadioBox.h>
#include <PullDownMenu.h>
#include <PopUpMenu.h>

class PToggleButton;

/*
 ToggleButton represents an information which has two possible states (on/off),
 It displays text like a Label object, but it has an additional indicator graphic
 (a square or a diamond shape) to the left of the label.
 The indicator shows the state of the ToggleButton: on or off.
 When the ToggleButton is on, the indicator is colored and appears to be pushed in.
 When the ToggleButton is off, the indicator appears to project outward.
 ToggleButton is used as component in Menus and items in CheckBox and RadioBox.
*/

class ToggleButton {

public:

  // An integer code is specified to each ToggleButton,
  // the menu (or CheckBox or RadioBox) returns this code when this ToggleButton is selected.
  // Each button must have a code unique in a particular container.

  ToggleButton(CheckBox &B, int code, const char* str,
	       Boolean initialState=GUIBool::STATE_OFF, 
	       const char *objectName=0,
	       ArgList userOptions=0, Cardinal nUserOptions=0);

  ToggleButton(RadioBox &B, int code, const char* str,
	       Boolean initialState=GUIBool::STATE_OFF, 
	       const char *objectName=0,
	       ArgList userOptions=0, Cardinal nUserOptions=0);

  ToggleButton(PullDownMenu &M, int code, const char* str,
	       Boolean initialState=GUIBool::STATE_OFF, 
	       char mnemonic='\0',
	       const char *accelerator=0,
	       const char *acceleratorText=0,
	       const char * objectName=0,
	       ArgList userOptions=0, Cardinal nUserOptions=0);

  ToggleButton(PopUpMenu &M, int code, const char* str,
	       Boolean initialState=GUIBool::STATE_OFF, 
	       char mnemonic='\0',
	       const char *accelerator=0,
	       const char *acceleratorText=0,
	       const char * objectName=0,
	       ArgList userOptions=0, Cardinal nUserOptions=0);

  // return current state of the object
  Boolean GetState();

  // initialize state of the object
  void SetState(Boolean newState);
  
  // Turn sensitive/insensitive the objet.
  //
  void Sensitive(Boolean sensitive=GUIBool::SENSITIVE);

  // Motif Resources :
  void Resources(Pixel armColor=Pixel(-1),
		 int defaultButtonShadowThickness=-1,
		 Boolean fillOnArm=GUIBool::DEFAULT,
		 char *accelerator=0,                  // ex. "Ctrl<Key>Q"
		 const char *acceleratorText=0,        // ex. "Ctrl+Q"
		 GUIAlignment::Value alignment=GUIAlignment::DEFAULT,
		 XmFontList fontList=XmFontList(-1),
		 const char *labelString=0,
		 int marginBottom=-1,
		 int marginHeight=-1,
		 int marginLeft=-1,
		 int marginRight=-1,
		 int marginTop=-1,
		 int marginWidth=-1,
		 char mnemonic='\0',
		 const char *mnemonicCharSet=0,
		 Boolean recomputeSize=GUIBool::DEFAULT);     

  ~ToggleButton();

  private :
  
  PToggleButton *impl;
};

#endif /* _SCPP_ToggleButton_h */
