// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: $
// 
// Contens:	XTerm.h
//
//		
//		
//
// Author :	Walter Pineda
//              EPFL DI-LTI     pineda@di.epfl.ch
//              1015 Ecublens   + 41 21 693 4652
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Tue May  9 1995
//
// $Author: $
// $Date:  $
// $Revision: $
// $State: $
// $Header:  $
// $Locker:  $
// $Log: $

#ifndef _SCPP_XTerm_h
#define _SCPP_XTerm_h

#include <scxx.h>
#include <GUI.h>
#include <EHXTerm.h>
#include <CharString.h>

class PXTerm;

/*
 XTerm simulates the behavior of a xterm : a window which displays and get from user text information.
 Methods are provided for indicate to the user application when information is typed.
 The editing capabilities are limited to text entered after last <return> key typed.
*/

active class XTerm : public XTermEventHandler {

 public:

  // sequential :
  //   If set to True it enforces sequential behavior of events :
  //      Application must always accept related events to this object in order
  //      to receive the next GUI event (avoid deadlocks with other possible GUI events)
  //   By default reception in order of GUI events is not provided allowing application
  //      to synchronize with GUI objects on demand

  XTerm(GUI &gui, const char* title, int rows=24, int columns=80, 
	int x=0, int y=0,
	Boolean editable=True, Boolean scrollbars=True, 
	ArgList userOptions=0, Cardinal nUserOptions=0, 
	Boolean sequential=False, int debug=0);

  // return the text typed between last two <enter>.
  // during tests : You shouldn't to type <enter>s very fast.
  //
  void ReadString(CharString &readText, 
		  Boolean sensitive=True, Boolean reset=False);

  // Append text at the end of the text that is currently displayed
  //
  void WriteString(const CharString &text); 

  void WriteString(const char *text); 

  // clear complete text contained in the object.
  //
  void Clear();

  // Turn sensitive/insensitive the objet.
  //
  void Sensitive(Boolean sensitive=True);

  ~XTerm();
  
  void EnterTypedEvent();  //private

  private :
  
  PXTerm *impl;

  Boolean sequentialBehavior;
  int readEnterOn;
  @XTerm();
};

#endif /* _SCPP_XTerm_h */
